# -*- coding: utf-8 -*-

# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindowFBP(object):
    def setupUi(self, MainWindowFBP):
        MainWindowFBP.setObjectName("MainWindowFBP")
        MainWindowFBP.resize(400, 680)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/fbp-logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindowFBP.setWindowIcon(icon)
        MainWindowFBP.setStatusTip("")
        self.centralwidget = QtWidgets.QWidget(MainWindowFBP)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.groupBoxAddReaction = QtWidgets.QGroupBox(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxAddReaction.sizePolicy().hasHeightForWidth())
        self.groupBoxAddReaction.setSizePolicy(sizePolicy)
        self.groupBoxAddReaction.setObjectName("groupBoxAddReaction")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBoxAddReaction)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem = QtWidgets.QSpacerItem(340, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.lineEditProducts = QtWidgets.QLineEdit(self.groupBoxAddReaction)
        self.lineEditProducts.setObjectName("lineEditProducts")
        self.gridLayout_4.addWidget(self.lineEditProducts, 1, 2, 1, 1)
        self.labelReactants = QtWidgets.QLabel(self.groupBoxAddReaction)
        self.labelReactants.setObjectName("labelReactants")
        self.gridLayout_4.addWidget(self.labelReactants, 0, 0, 1, 1)
        self.lineEditReactants = QtWidgets.QLineEdit(self.groupBoxAddReaction)
        self.lineEditReactants.setObjectName("lineEditReactants")
        self.gridLayout_4.addWidget(self.lineEditReactants, 1, 0, 1, 1)
        self.labelProducts = QtWidgets.QLabel(self.groupBoxAddReaction)
        self.labelProducts.setObjectName("labelProducts")
        self.gridLayout_4.addWidget(self.labelProducts, 0, 2, 1, 1)
        self.labelInhibitors = QtWidgets.QLabel(self.groupBoxAddReaction)
        self.labelInhibitors.setObjectName("labelInhibitors")
        self.gridLayout_4.addWidget(self.labelInhibitors, 0, 4, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBoxAddReaction)
        self.label_2.setObjectName("label_2")
        self.gridLayout_4.addWidget(self.label_2, 1, 3, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBoxAddReaction)
        self.label.setObjectName("label")
        self.gridLayout_4.addWidget(self.label, 1, 1, 1, 1)
        self.lineEditInhibitors = QtWidgets.QLineEdit(self.groupBoxAddReaction)
        self.lineEditInhibitors.setObjectName("lineEditInhibitors")
        self.gridLayout_4.addWidget(self.lineEditInhibitors, 1, 4, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout_4, 0, 0, 1, 2)
        self.pushButtonAdd = QtWidgets.QPushButton(self.groupBoxAddReaction)
        self.pushButtonAdd.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonAdd.sizePolicy().hasHeightForWidth())
        self.pushButtonAdd.setSizePolicy(sizePolicy)
        self.pushButtonAdd.setMinimumSize(QtCore.QSize(90, 0))
        icon = QtGui.QIcon.fromTheme("list-add")
        self.pushButtonAdd.setIcon(icon)
        self.pushButtonAdd.setObjectName("pushButtonAdd")
        self.gridLayout_2.addWidget(self.pushButtonAdd, 1, 1, 1, 1)
        self.gridLayout_6.addWidget(self.groupBoxAddReaction, 0, 0, 1, 1)
        self.groupBoxReactionSystem = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBoxReactionSystem.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxReactionSystem.sizePolicy().hasHeightForWidth())
        self.groupBoxReactionSystem.setSizePolicy(sizePolicy)
        self.groupBoxReactionSystem.setObjectName("groupBoxReactionSystem")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBoxReactionSystem)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.pushButtonDelete = QtWidgets.QPushButton(self.groupBoxReactionSystem)
        self.pushButtonDelete.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonDelete.sizePolicy().hasHeightForWidth())
        self.pushButtonDelete.setSizePolicy(sizePolicy)
        self.pushButtonDelete.setMinimumSize(QtCore.QSize(90, 0))
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.pushButtonDelete.setIcon(icon)
        self.pushButtonDelete.setObjectName("pushButtonDelete")
        self.gridLayout_3.addWidget(self.pushButtonDelete, 2, 2, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem1, 2, 0, 1, 2)
        self.listWidgetReactions = QtWidgets.QListWidget(self.groupBoxReactionSystem)
        self.listWidgetReactions.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.listWidgetReactions.setAlternatingRowColors(True)
        self.listWidgetReactions.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.listWidgetReactions.setResizeMode(QtWidgets.QListView.Adjust)
        self.listWidgetReactions.setViewMode(QtWidgets.QListView.ListMode)
        self.listWidgetReactions.setModelColumn(0)
        self.listWidgetReactions.setObjectName("listWidgetReactions")
        self.gridLayout_3.addWidget(self.listWidgetReactions, 0, 0, 2, 3)
        self.gridLayout_6.addWidget(self.groupBoxReactionSystem, 1, 0, 1, 1)
        self.groupBoxCalculator = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBoxCalculator.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxCalculator.sizePolicy().hasHeightForWidth())
        self.groupBoxCalculator.setSizePolicy(sizePolicy)
        self.groupBoxCalculator.setObjectName("groupBoxCalculator")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBoxCalculator)
        self.gridLayout_5.setObjectName("gridLayout_5")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem2, 3, 0, 1, 1)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.labelSymbols = QtWidgets.QLabel(self.groupBoxCalculator)
        self.labelSymbols.setObjectName("labelSymbols")
        self.gridLayout.addWidget(self.labelSymbols, 1, 0, 1, 1)
        self.lineEditCalculatorSymbols = QtWidgets.QLineEdit(self.groupBoxCalculator)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditCalculatorSymbols.sizePolicy().hasHeightForWidth())
        self.lineEditCalculatorSymbols.setSizePolicy(sizePolicy)
        self.lineEditCalculatorSymbols.setObjectName("lineEditCalculatorSymbols")
        self.gridLayout.addWidget(self.lineEditCalculatorSymbols, 2, 0, 1, 1)
        self.labelSteps = QtWidgets.QLabel(self.groupBoxCalculator)
        self.labelSteps.setMinimumSize(QtCore.QSize(50, 0))
        self.labelSteps.setObjectName("labelSteps")
        self.gridLayout.addWidget(self.labelSteps, 1, 1, 1, 1)
        self.spinBoxCalculatorSteps = QtWidgets.QSpinBox(self.groupBoxCalculator)
        self.spinBoxCalculatorSteps.setMinimumSize(QtCore.QSize(50, 0))
        self.spinBoxCalculatorSteps.setMinimum(1)
        self.spinBoxCalculatorSteps.setMaximum(9999)
        self.spinBoxCalculatorSteps.setObjectName("spinBoxCalculatorSteps")
        self.gridLayout.addWidget(self.spinBoxCalculatorSteps, 2, 1, 1, 1)
        self.gridLayout_5.addLayout(self.gridLayout, 0, 0, 1, 2)
        self.pushButtonCalculate = QtWidgets.QPushButton(self.groupBoxCalculator)
        self.pushButtonCalculate.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonCalculate.sizePolicy().hasHeightForWidth())
        self.pushButtonCalculate.setSizePolicy(sizePolicy)
        self.pushButtonCalculate.setMinimumSize(QtCore.QSize(90, 0))
        self.pushButtonCalculate.setObjectName("pushButtonCalculate")
        self.gridLayout_5.addWidget(self.pushButtonCalculate, 3, 1, 1, 1)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_3 = QtWidgets.QLabel(self.groupBoxCalculator)
        self.label_3.setObjectName("label_3")
        self.verticalLayout.addWidget(self.label_3)
        self.tableWidgetProperties = QtWidgets.QTableWidget(self.groupBoxCalculator)
        self.tableWidgetProperties.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidgetProperties.sizePolicy().hasHeightForWidth())
        self.tableWidgetProperties.setSizePolicy(sizePolicy)
        self.tableWidgetProperties.setMinimumSize(QtCore.QSize(0, 97))
        self.tableWidgetProperties.setMaximumSize(QtCore.QSize(16777215, 97))
        self.tableWidgetProperties.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.tableWidgetProperties.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidgetProperties.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tableWidgetProperties.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableWidgetProperties.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.tableWidgetProperties.setShowGrid(False)
        self.tableWidgetProperties.setGridStyle(QtCore.Qt.SolidLine)
        self.tableWidgetProperties.setObjectName("tableWidgetProperties")
        self.tableWidgetProperties.setColumnCount(0)
        self.tableWidgetProperties.setRowCount(2)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetProperties.setVerticalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetProperties.setVerticalHeaderItem(1, item)
        self.tableWidgetProperties.horizontalHeader().setDefaultSectionSize(150)
        self.verticalLayout.addWidget(self.tableWidgetProperties)
        self.gridLayout_5.addLayout(self.verticalLayout, 2, 0, 1, 2)
        self.line = QtWidgets.QFrame(self.groupBoxCalculator)
        self.line.setLineWidth(0)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_5.addWidget(self.line, 1, 0, 1, 1)
        self.gridLayout_6.addWidget(self.groupBoxCalculator, 2, 0, 1, 1)
        MainWindowFBP.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindowFBP)
        self.statusbar.setObjectName("statusbar")
        MainWindowFBP.setStatusBar(self.statusbar)
        self.toolBarFile = QtWidgets.QToolBar(MainWindowFBP)
        self.toolBarFile.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBarFile.setObjectName("toolBarFile")
        MainWindowFBP.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarFile)
        self.menubar = QtWidgets.QMenuBar(MainWindowFBP)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 400, 22))
        self.menubar.setDefaultUp(False)
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindowFBP.setMenuBar(self.menubar)
        self.actionOpen = QtWidgets.QAction(MainWindowFBP)
        icon = QtGui.QIcon.fromTheme("document-open")
        self.actionOpen.setIcon(icon)
        self.actionOpen.setObjectName("actionOpen")
        self.actionSave = QtWidgets.QAction(MainWindowFBP)
        self.actionSave.setEnabled(False)
        icon = QtGui.QIcon.fromTheme("document-save")
        self.actionSave.setIcon(icon)
        self.actionSave.setObjectName("actionSave")
        self.actionSave_as = QtWidgets.QAction(MainWindowFBP)
        self.actionSave_as.setEnabled(True)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.actionSave_as.setIcon(icon)
        self.actionSave_as.setObjectName("actionSave_as")
        self.actionQuit = QtWidgets.QAction(MainWindowFBP)
        icon = QtGui.QIcon.fromTheme("application-exit")
        self.actionQuit.setIcon(icon)
        self.actionQuit.setObjectName("actionQuit")
        self.actionNew = QtWidgets.QAction(MainWindowFBP)
        self.actionNew.setEnabled(True)
        icon = QtGui.QIcon.fromTheme("document-new")
        self.actionNew.setIcon(icon)
        self.actionNew.setMenuRole(QtWidgets.QAction.TextHeuristicRole)
        self.actionNew.setObjectName("actionNew")
        self.actionAbout = QtWidgets.QAction(MainWindowFBP)
        self.actionAbout.setObjectName("actionAbout")
        self.toolBarFile.addAction(self.actionNew)
        self.toolBarFile.addAction(self.actionOpen)
        self.toolBarFile.addSeparator()
        self.toolBarFile.addAction(self.actionSave)
        self.toolBarFile.addAction(self.actionSave_as)
        self.toolBarFile.addSeparator()
        self.toolBarFile.addAction(self.actionQuit)
        self.menuFile.addAction(self.actionNew)
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSave)
        self.menuFile.addAction(self.actionSave_as)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindowFBP)
        self.lineEditReactants.returnPressed.connect(self.pushButtonAdd.click)
        self.lineEditProducts.returnPressed.connect(self.pushButtonAdd.click)
        self.lineEditInhibitors.returnPressed.connect(self.pushButtonAdd.click)
        self.lineEditCalculatorSymbols.returnPressed.connect(self.pushButtonCalculate.click)
        QtCore.QMetaObject.connectSlotsByName(MainWindowFBP)
        MainWindowFBP.setTabOrder(self.lineEditReactants, self.lineEditProducts)
        MainWindowFBP.setTabOrder(self.lineEditProducts, self.lineEditInhibitors)
        MainWindowFBP.setTabOrder(self.lineEditInhibitors, self.pushButtonAdd)
        MainWindowFBP.setTabOrder(self.pushButtonAdd, self.lineEditCalculatorSymbols)
        MainWindowFBP.setTabOrder(self.lineEditCalculatorSymbols, self.spinBoxCalculatorSteps)
        MainWindowFBP.setTabOrder(self.spinBoxCalculatorSteps, self.pushButtonCalculate)
        MainWindowFBP.setTabOrder(self.pushButtonCalculate, self.tableWidgetProperties)
        MainWindowFBP.setTabOrder(self.tableWidgetProperties, self.pushButtonDelete)
        MainWindowFBP.setTabOrder(self.pushButtonDelete, self.listWidgetReactions)

    def retranslateUi(self, MainWindowFBP):
        _translate = QtCore.QCoreApplication.translate
        MainWindowFBP.setWindowTitle(_translate("MainWindowFBP", "FBP Calculator"))
        self.groupBoxAddReaction.setTitle(_translate("MainWindowFBP", "Add a reaction"))
        self.lineEditProducts.setStatusTip(_translate("MainWindowFBP", "example: D E F (can\'t be empty)"))
        self.labelReactants.setText(_translate("MainWindowFBP", "Reactants:"))
        self.lineEditReactants.setStatusTip(_translate("MainWindowFBP", "example: A B C (can\'t be empty)"))
        self.labelProducts.setText(_translate("MainWindowFBP", "Products:"))
        self.labelInhibitors.setText(_translate("MainWindowFBP", "Inhibitors:"))
        self.label_2.setText(_translate("MainWindowFBP", " | "))
        self.label.setText(_translate("MainWindowFBP", "⟶"))
        self.lineEditInhibitors.setStatusTip(_translate("MainWindowFBP", "Example: F G (can be empty)"))
        self.pushButtonAdd.setStatusTip(_translate("MainWindowFBP", "Add a reaction (reactants and products required)"))
        self.pushButtonAdd.setText(_translate("MainWindowFBP", "Add"))
        self.groupBoxReactionSystem.setTitle(_translate("MainWindowFBP", "Reaction System"))
        self.pushButtonDelete.setStatusTip(_translate("MainWindowFBP", "Remove selected reactions"))
        self.pushButtonDelete.setText(_translate("MainWindowFBP", "Delete"))
        self.groupBoxCalculator.setTitle(_translate("MainWindowFBP", "Calculator"))
        self.labelSymbols.setText(_translate("MainWindowFBP", "Symbols:"))
        self.lineEditCalculatorSymbols.setStatusTip(_translate("MainWindowFBP", "Example: A B C"))
        self.labelSteps.setText(_translate("MainWindowFBP", "Steps:"))
        self.spinBoxCalculatorSteps.setStatusTip(_translate("MainWindowFBP", "Example: 3"))
        self.pushButtonCalculate.setStatusTip(_translate("MainWindowFBP", "Calculate formula based predictor"))
        self.pushButtonCalculate.setText(_translate("MainWindowFBP", "Calculate"))
        self.label_3.setText(_translate("MainWindowFBP", "Context properties:"))
        item = self.tableWidgetProperties.verticalHeaderItem(1)
        item.setText(_translate("MainWindowFBP", "¬ "))
        self.toolBarFile.setWindowTitle(_translate("MainWindowFBP", "File"))
        self.menuFile.setTitle(_translate("MainWindowFBP", "File"))
        self.menuHelp.setTitle(_translate("MainWindowFBP", "Help"))
        self.actionOpen.setText(_translate("MainWindowFBP", "Open..."))
        self.actionOpen.setToolTip(_translate("MainWindowFBP", "Open"))
        self.actionOpen.setStatusTip(_translate("MainWindowFBP", "Open an existing reaction system"))
        self.actionOpen.setShortcut(_translate("MainWindowFBP", "Ctrl+O"))
        self.actionSave.setText(_translate("MainWindowFBP", "Save"))
        self.actionSave.setToolTip(_translate("MainWindowFBP", "Save"))
        self.actionSave.setStatusTip(_translate("MainWindowFBP", "Save changes"))
        self.actionSave.setShortcut(_translate("MainWindowFBP", "Ctrl+S"))
        self.actionSave_as.setText(_translate("MainWindowFBP", "Save As..."))
        self.actionSave_as.setToolTip(_translate("MainWindowFBP", "Save As"))
        self.actionSave_as.setStatusTip(_translate("MainWindowFBP", "Save changes under a new name"))
        self.actionSave_as.setShortcut(_translate("MainWindowFBP", "Ctrl+Shift+S"))
        self.actionQuit.setText(_translate("MainWindowFBP", "Quit"))
        self.actionQuit.setStatusTip(_translate("MainWindowFBP", "Close the application"))
        self.actionQuit.setShortcut(_translate("MainWindowFBP", "Ctrl+Q"))
        self.actionNew.setText(_translate("MainWindowFBP", "New..."))
        self.actionNew.setToolTip(_translate("MainWindowFBP", "New"))
        self.actionNew.setStatusTip(_translate("MainWindowFBP", "Create a new reaction system"))
        self.actionNew.setShortcut(_translate("MainWindowFBP", "Ctrl+N"))
        self.actionAbout.setText(_translate("MainWindowFBP", "About"))

from . import resources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindowFBP = QtWidgets.QMainWindow()
    ui = Ui_MainWindowFBP()
    ui.setupUi(MainWindowFBP)
    MainWindowFBP.show()
    sys.exit(app.exec_())

